# coding: utf-8
#

import wda


def test_xpath(app: wda.Client):
    with app:
        app.xpath("//*[@label='蓝牙']").click()
        assert app.xpath('//*[@label="设置"]').wait()
        assert app.xpath('//*[@label="设置"]').get().label == "设置"

        # test __getattr__
        assert app.xpath('//*[@label="设置"]').label == "设置"


#

__all__ = ['AppiumSettings', 'AlertAction']


import enum

class AppiumSettings(str, enum.Enum):
    """
    {'boundElementsByIndex': False,
    'shouldUseCompactResponses': True,
    'mjpegServerFramerate': 10,
    'snapshotMaxDepth': 50,
    'screenshotOrientation': 'auto',
    'activeAppDetectionPoint': '64.00,64.00',
    'acceptAlertButtonSelector': '',
    'snapshotTimeout': 15,
    'elementResponseAttributes': 'type,label',
    'keyboardPrediction': 0,
    'screenshotQuality': 2,
    'keyboardAutocorrection': 0,
    'useFirstMatch': False,
    'reduceMotion': False,
    'defaultActiveApplication': 'auto',
    'mjpegScalingFactor': 100,
    'mjpegServerScreenshotQuality': 25,
    'dismissAlertButtonSelector': '',
    'includeNonModalElements': False}
    """
    AcceptAlertButtonSelector = "acceptAlertButtonSelector"
    DismissAlertButtonSelector = "dismissAlertButtonSelector"



# default_alert_accept_selector = "**/XCUIElementTypeButton[`label IN {'允许','好','仅在使用应用期间','暂不'}`]"
# default_alert_dismiss_selector = "**/XCUIElementTypeButton[`label IN {'不允许','暂不'}`]"


class AlertAction(str, enum.Enum):
    ACCEPT = "accept"
    DISMISS = "dismiss"




# coding: utf-8

import inspect


def inject_call(fn, *args, **kwargs):
    """
    Call function without known all the arguments

    Args:
        fn: function
        args: arguments
        kwargs: key-values
    
    Returns:
        as the fn returns
    """
    assert callable(fn), "first argument must be callable"

    st = inspect.signature(fn)
    fn_kwargs = {
        key: kwargs[key]
        for key in st.parameters.keys() if key in kwargs
    }
    ba = st.bind(*args, **fn_kwargs)
    ba.apply_defaults()
    return fn(*ba.args, **ba.kwargs)